##  Guidelines and Best Practices
  * Start your journey with business capabilities (BCs) by reviewing the [SAP LeanIX best practices recommendations for business capability maps![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fwiki%2Fea%2Fbusiness-capability-map-examples-and-templates "https://www.leanix.net/en/wiki/ea/business-capability-map-examples-and-templates"), customized by the industry.
  * For a jumpstart (if you are a maturing EA practice with no defined business capability maps), you can import a reference business capability map in SAP LeanIX using the reference catalog. When importing business capability maps, you can select the entire or parts of the best-practice hierarchies of business capabilities to be imported to your workspace. For more information, see [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.").
  * BCs are the "common language” between business & IT; stakeholders from both are needed to define BCs.
  * Create a hierarchy of business capabilities to visualize and comprehend the range of capabilities your business requires to deliver value. Start by identifying the high-level core capabilities, which are referred to as Level 1 capabilities. Then, break down each core capability into more specific Level 2 capabilities. Depending on the complexity of your business, you may need to further break down those capabilities into even more specific Level 3 capabilities.
  * Limit top-level business capabilities to 7-10 for most cases (or up to 20 for more complex cases). The highest level capabilities should be a complete description of your business.
  * BCs are mutually exclusive. A good test is to check whether you can assign Level 2 capabilities without ambiguity.
  * Illustrate the breadth of your organization’s business capabilities by going down no more than three levels. This will be enough to represent the IT landscape of your enterprise. When you start working with SAP LeanIX, we recommend focusing on one area and two levels to realize the fast time to value before you move on with your following use cases.
  * Not all SAP LeanIX customers use a lifecycle on business capabilities. Scenarios in which the lifecycle is being used and SAP LeanIX recommends doing so:
    * Reflect that this belongs to a model that the organization phased out
    * When your organization ran a capability-based planning and decided to shut down or create a specific capability (which would then be supported by applications, needs a project to shut down or introduce those applications, etc.)
    * If your organization wants to bring in or scale up new capabilities through M&A or expansion (e.g., offering B2C services on top of existing B2B)
    * If your organization wants to retire capabilities through divestiture, retirement of products, or entire business models.
  * Modeling predecessors and successors for business capabilities is not frequently used and is rather something for big structural changes in the organization.
  * Advanced: Use the [Pace Layering](https://help.sap.com/docs/leanix/ea/pace-layering?locale=en-US&state=PRODUCTION&version=CLOUD) approach to allow are more differentiated view of your enterprise architecture for your EA initiatives.


Advanced: When working with SAP LeanIX, you typically begin by modeling business capabilities, applications, and organizations. One next step could be to link your business capabilities to your organization’s strategy/objectives via the objective fact sheet.
